==> netbeans_8.0.2+dfsg1.orig.tar.xz: netbeans-8.0.2/cnd.utils/src/org/netbeans/modules/cnd/utils/filters/AllLibraryFileFilter.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
 *
 * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
 * Other names may be trademarks of their respective owners.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common
 * Development and Distribution License("CDDL") (collectively, the
 * "License"). You may not use this file except in compliance with the
 * License. You can obtain a copy of the License at
 * http://www.netbeans.org/cddl-gplv2.html
 * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
 * specific language governing permissions and limitations under the
 * License.  When distributing the software, include this License Header
 * Notice in each file and include the License file at
 * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the GPL Version 2 section of the License file that
 * accompanied this code. If applicable, add the following below the
 * License Header, with the fields enclosed by brackets [] replaced by
 * your own identifying information:
 * "Portions Copyrighted [year] [name of copyright owner]"
 *
 * Contributor(s):
 *
 * The Original Software is NetBeans. The Initial Developer of the Original
 * Software is Sun Microsystems, Inc. Portions Copyright 1997-2007 Sun
 * Microsystems, Inc. All Rights Reserved.
 *
 * If you wish your version of this file to be governed by only the CDDL
 * or only the GPL Version 2, indicate your decision by adding
 * "[Contributor] elects to include this software in this distribution
 * under the [CDDL or GPL Version 2] license." If you do not indicate a
 * single choice of license, a recipient has the option to distribute
 * your version of this file under either the CDDL, the GPL Version 2 or
 * to extend the choice of license to its licensees as provided above.
 * However, if you add GPL Version 2 code and therefore, elected the GPL
 * Version 2 license, then the option applies only if the new code is
 * made subject to such option by the copyright holder.
 */

package org.netbeans.modules.cnd.utils.filters;

import java.io.File;
import java.util.ArrayList;
import java.util.List;
import org.netbeans.modules.cnd.utils.FileFilterFactory.AbstractFileAndFileObjectFilter;
import org.openide.filesystems.FileObject;
import org.openide.util.NbBundle;
import org.openide.util.Utilities;

public class AllLibraryFileFilter extends AbstractFileAndFileObjectFilter {

    private static AllLibraryFileFilter instance = null;

    private List<AbstractFileAndFileObjectFilter> filters = new ArrayList<AbstractFileAndFileObjectFilter>();

    public static AllLibraryFileFilter getInstance() {
        if (instance == null) {
            instance = new AllLibraryFileFilter();
        }
        return instance;
    }

    private AllLibraryFileFilter() {
        filters.add(ElfStaticLibraryFileFilter.getInstance());
        if (Utilities.isWindows()) {
            filters.add(PeDynamicLibraryFileFilter.getInstance());
            filters.add(PeStaticLibraryFileFilter.getInstance());
        } else if (Utilities.getOperatingSystem() == Utilities.OS_MAC) {
            filters.add(MacOSXDynamicLibraryFileFilter.getInstance());
        } else {
            filters.add(ElfDynamicLibraryFileFilter.getInstance());
        }
    }

    @Override
    public String getDescription() {
        return NbBundle.getMessage(AllLibraryFileFilter.class, "ALL_LIB_FILTER"); // NOI18N
    }

    @Override
    public boolean accept(File f) {
        for(AbstractFileAndFileObjectFilter filter: filters) {
            if (filter.accept(f)) {
                return true;
            }
        }
        return false;
    }

    @Override
    public boolean accept(FileObject fileObject) {
        for(AbstractFileAndFileObjectFilter filter: filters) {
            if (filter.accept(fileObject)) {
                return true;
            }
        }
        return false;
    }

    @Override
    public String getSuffixesAsString() {
        return "";
    }
}

==> netbeans_8.1+dfsg3.orig.tar.xz: netbeans-8.1/cnd.utils/src/org/netbeans/modules/cnd/utils/filters/AllLibraryFileFilter.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
 *
 * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
 * Other names may be trademarks of their respective owners.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common
 * Development and Distribution License("CDDL") (collectively, the
 * "License"). You may not use this file except in compliance with the
 * License. You can obtain a copy of the License at
 * http://www.netbeans.org/cddl-gplv2.html
 * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
 * specific language governing permissions and limitations under the
 * License.  When distributing the software, include this License Header
 * Notice in each file and include the License file at
 * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the GPL Version 2 section of the License file that
 * accompanied this code. If applicable, add the following below the
 * License Header, with the fields enclosed by brackets [] replaced by
 * your own identifying information:
 * "Portions Copyrighted [year] [name of copyright owner]"
 *
 * Contributor(s):
 *
 * The Original Software is NetBeans. The Initial Developer of the Original
 * Software is Sun Microsystems, Inc. Portions Copyright 1997-2007 Sun
 * Microsystems, Inc. All Rights Reserved.
 *
 * If you wish your version of this file to be governed by only the CDDL
 * or only the GPL Version 2, indicate your decision by adding
 * "[Contributor] elects to include this software in this distribution
 * under the [CDDL or GPL Version 2] license." If you do not indicate a
 * single choice of license, a recipient has the option to distribute
 * your version of this file under either the CDDL, the GPL Version 2 or
 * to extend the choice of license to its licensees as provided above.
 * However, if you add GPL Version 2 code and therefore, elected the GPL
 * Version 2 license, then the option applies only if the new code is
 * made subject to such option by the copyright holder.
 */

package org.netbeans.modules.cnd.utils.filters;

import java.io.File;
import java.util.ArrayList;
import java.util.List;
import org.netbeans.modules.cnd.utils.FileFilterFactory.AbstractFileAndFileObjectFilter;
import org.openide.filesystems.FileObject;
import org.openide.util.NbBundle;
import org.openide.util.Utilities;

public class AllLibraryFileFilter extends AbstractFileAndFileObjectFilter {

    private static AllLibraryFileFilter instance = null;

    private final List<AbstractFileAndFileObjectFilter> filters = new ArrayList<AbstractFileAndFileObjectFilter>();

    public static AllLibraryFileFilter getInstance() {
        if (instance == null) {
            instance = new AllLibraryFileFilter();
        }
        return instance;
    }

    private AllLibraryFileFilter() {
        filters.add(ElfStaticLibraryFileFilter.getInstance());
        if (Utilities.isWindows()) {
            filters.add(PeDynamicLibraryFileFilter.getInstance());
            filters.add(PeStaticLibraryFileFilter.getInstance());
        } else if (Utilities.getOperatingSystem() == Utilities.OS_MAC) {
            filters.add(MacOSXDynamicLibraryFileFilter.getInstance());
        } else {
            filters.add(ElfDynamicLibraryFileFilter.getInstance());
        }
    }

    @Override
    public String getDescription() {
        return NbBundle.getMessage(AllLibraryFileFilter.class, "ALL_LIB_FILTER"); // NOI18N
    }

    @Override
    public boolean accept(File f) {
        for(AbstractFileAndFileObjectFilter filter: filters) {
            if (filter.accept(f)) {
                return true;
            }
        }
        return false;
    }

    @Override
    public boolean accept(FileObject fileObject) {
        for(AbstractFileAndFileObjectFilter filter: filters) {
            if (filter.accept(fileObject)) {
                return true;
            }
        }
        return false;
    }

    @Override
    public String getSuffixesAsString() {
        return "";
    }
}
